@@ -42,7 +42,7 @@ class QueryRequestWriter(MessageWriter):
                  custom=False,
                  cypher=None,
                  write_transaction=False,
-                 split_results=False,
+                 aggregate_results=False,
                  publish_to=None,
                  returns={}):
 
@@ -57,7 +57,7 @@ class QueryRequestWriter(MessageWriter):
         self.custom = custom
         self.cypher = cypher
         self.write_transaction = write_transaction
-        self.split_results = split_results
+        self.aggregate_results = aggregate_results
         self.publish_to = publish_to
         self.returns = returns
 
@@ -77,7 +77,7 @@ class QueryRequestWriter(MessageWriter):
             custom_fields = {
                 "cypher": self.cypher,
                 "writeTransaction": self.write_transaction,
-                "splitResults": self.split_results,
+                "aggregateResults": self.aggregate_results,
                 "publishTo": self.publish_to,
                 "returns": self.returns
             }
@@ -96,6 +96,7 @@ class QueryResponseWriter(MessageWriter):
                  query_name,
                  result_summary,
                  graph):
+                 #pattern):
 
         super().__init__(
                          sender,
@@ -108,6 +109,8 @@ class QueryResponseWriter(MessageWriter):
         self.graph = graph
         self.nodes = []
         self.relationships = []
+        #self.pattern = pattern
+        self.supported_patterns = ['node', 'relationship']
 
         if self.graph:
             for node in self.graph.nodes:
@@ -116,37 +119,51 @@ class QueryResponseWriter(MessageWriter):
             for relationship in self.graph.relationships:
                 self.relationships.append(relationship)
 
-    def format_json_message(self):
+        if self.relationships:
+            self.pattern = "relationship"
+        else:
+            self.pattern = "node"
+
+    def return_json_with_all_nodes(self):
+        if self.pattern == 'relationship':
+            raise ValueError("Cannot use this method to publish relationships. Use 'generate_separate_entity_jsons()' instead.")
+
         message = super().format_json_header()
 
         body = {
            "body": {
                     "queryName": self.query_name,
                     "nodes": [self._get_node_dict(node) for node in self.nodes],
-                    "relationships": [self._get_relationship_dict(rel) for rel in self.relationships],
+                    # Note: Each relationship triple should be delivered separately using 
+                    # the generate_individual_jsons() method.
+                    "relationship": {},
+                    #"relationships": [self._get_relationship_dict(rel) for rel in self.relationships],
                     "resultSummary": self._get_result_summary_dict(self.result_summary)
            }
         }
         message.update(body)
         return message
 
-    def format_json_message_iter(self):
-        for entity in self.nodes + self.relationships:
-            yield self._format_json_message_single_result(entity)
+    def generate_separate_entity_jsons(self):
+        summary_dict = self._get_result_summary_dict(self.result_summary)
 
-    def _format_json_message_single_result(self, entity):
-        result_nodes = None
-        result_relationship = None
-
-        if isinstance(entity, neo4j.graph.Node):
-            node = [entity]
-            relationship = []
-        elif isinstance(entity, neo4j.graph.Relationship):
-            node = []
-            relationship = [entity]
-
-        result_summary_dict = self._get_result_summary_dict(self.result_summary)
+        if self.pattern == "node":
+            for node in self.nodes:
+                yield self._format_json_message(
+                                                nodes = [node],
+                                                relationship = {},
+                                                result_summary = summary_dict)
+        elif self.pattern == "relationship":
+            for relationship in self.relationships:
+                relationship_dict = self._get_relationship_dict(relationship)
+                yield self._format_json_message(
+                                                nodes = [],
+                                                relationship = relationship_dict,
+                                                result_summary = summary_dict)
+        else:
+            raise ValueError(f"Pattern '{self.pattern}' not in supported patterns: {self.supported_patterns}.")
 
+    def _format_json_message(self, nodes, relationship, result_summary):
         message = {
            "header": {
                       "messageKind": self.message_kind,
@@ -156,9 +173,10 @@ class QueryResponseWriter(MessageWriter):
            },
            "body": {
                     "queryName": self.query_name,
-                    "nodes": node,
-                    "relationships": relationship,
-                    "resultSummary": self._get_result_summary_dict(self.result_summary)
+                    "nodes": nodes,
+                    "relationship": relationship,
+                    "resultSummary": result_summary,
+                    #"pattern": self.pattern
            }
         }
         return message
@@ -236,6 +254,7 @@ class JobCreatedWriter(MessageWriter):
     def format_json_message(self):
         pass
 
+
 class MessageReader(object):
 
     def __init__(
@@ -290,7 +309,7 @@ class QueryRequestReader(MessageReader):
         if self.custom:
             self.cypher = self.body['cypher']
             self.write_transaction = bool(self.body['writeTransaction'])
-            self.split_results = bool(self.body['splitResults'])
+            self.aggregate_results = bool(self.body['aggregateResults'])
             self.publish_to = self.body.get('publishTo')
             self.returns = self.body.get('returns')
 
@@ -310,7 +329,8 @@ class QueryResponseReader(MessageReader):
         self.query_name = self.body['queryName']
         self.result_summary = self.body['resultSummary']
         self.nodes = self.body['nodes']
-        self.relationships = self.body['relationships']
+        self.relationship = self.body['relationship']
+        #self.pattern = self.body['pattern']
 
 
 class JobCreatedReader(MessageReader):
